package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````D1D!`#0```"TL@````0`!30`(``)
M`"@`'``;``$``'`,GP``#)\!``R?`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0`8GP``&)\```4```````$`
M`0```/2N``#TK@(`]*X"`#0"``!X$@``!@```````0`"`````*\```"O`@``
MKP(```$````!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D]*X`
M`/2N`@#TK@(`#`$```P!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50#0E35RB1^&"+'X+#I%H%L4<MC*XV$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`D`$D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#0````\`
M```0````$0```!,````6`````````````````````````!@````;````'```
M```````@````(0```"(`````````(P```"0````H`````````"H`````````
M`````"L````L````+0```"X`````````,@```#,`````````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$<`
M``!(````20```$H`````````2P``````````````````````````````````
M`$P```!-`````````$\`````````40```%,```!5````````````````````
M`````%8```!:`````````%P`````````7@````````!@````80``````````
M````8P```&0```!F````9P```&H```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75[%#N$>.&^9R!?>T1#[J5DQQ;FCL/04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[
MP\)*(GW_"HH05^W>DQRM2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.BIC=PF]Z:?J3K01B-^/PP4/R[\C?A2!/5Z2;EL6YG$!0&WU?
M,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^J9R;8M#Z@NPL]HMK
M?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM.0T7ZEKQH^#[2>)7
MQ!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````
M`!$``````````````"`````M```````````````@````/```````````````
M(````%```````````````"````!2`P`````````````2````%0(`````````
M````$@```*P"`````````````!(```"0`@`````````````2````100``!BQ
M`@``````(``7`)L!`````````````!(```")`@`````````````2````BP$`
M`#`5`0``````$@```*X#```HL0(``````!``&`!#`@`````````````2````
M;@(`````````````$@```(4$```DL0(`!````!$`%P#O`@`````````````2
M````T00```E:`0">`@``$@`-`"H$``!]3P$`J````!(`#0!9`P``````````
M```2````5`(`````````````$@`````#`````````````!(```"]`P``;,$"
M```````0`!@`"`0`````````````$@```#8$``#)4@$`0`<``!(`#0!?!```
M24T!`)(````2``T`'00``&5/`0`6````$@`-`'L"`````````````!(````^
M`@`````````````2````9`$`````````````$@```-P"`````````````!(`
M``!L`P``*+$"``0````A`!@`_0$`````````````$@````0"````````````
M`!(```">`@`````````````2````FP,``"BQ`@``````$``7`+D"````````
M`````!(```"'````6!<!```````2````@P(`````````````$@```"0#````
M`````````!(```#W`0`````````````2````'0(`````````````$@```&T#
M```HL0(`!````"$`&`#(`P``;,$"```````0`!@`^0(``$"Q`@`$````$0`8
M`-4#``!!70$``@```!(`#0!O`0`````````````2````2P$`````````````
M$@```'4$```%70$`/````!(`#0"Q!```#5(!`+P````2``T`WP,``$1=`0``
M````$@`.`%T"`````````````!(```!)!```D1D!```````2``T`G@0``)@4
M`0``````$@`+`*<``````````````!(```#.`@`````````````2````ZP``
M`#RQ`@`!````$0`8`)<"`````````````!(```!0!```3%T!``0````1``\`
MH@,``"BQ`@``````$``8`"L#`````````````!(```!#`P`````````````2
M````:@``````````````$@```/@``````````````!(```"<!```U4P!`#``
M```2``T`%`$`````````````$@```-`#``!LP0(``````!``&`"D!```X4T!
M`(0!```2``T`O```````````````$@```"P"`````````````!(```#C`0``
M```````````2````?0$`````````````$@```,H``````````````!(```#<
M```````````````2````"0$``#BQ`@`$````$0`8`&L#```HL0(`!````!$`
M&``]`0`````````````2````I0(`````````````$@```+P#``!LP0(`````
M`!``&`##!```K5$!`%`````2``T`F```````````````$@```.<"````````
M`````!(```!#!```&+$"```````0`!<`-0,`````````````$@```(D#```P
ML0(`!````!$`&`#V`P``_5$!`!`````2``T`N0$`````````````$@```*8!
M`````````````!(```!F`P``X1<!`*X!```2``T`&0$`````````````$@``
M`!`#`````````````!(````'`P`````````````2````Q`$``$2Q`@`3````
M$0`8`,<"`````````````!(```"S`@`````````````2````2P(`````````
M````$@```+(!`````````````!(```!+`P`````````````2````CP0``"50
M`0"(`0``$@`-`!<#`````````````!(````>`0`````````````2````=0(`
M````````````$@```!$$``"I7`$`3````!(`#0!X```````````````2````
M6P$`````````````$@```.4#``#=30$`!````!(`#0`J`0``X!8!```````2
M`````&QI8G!E<FPN<V\N-2XR,@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K
M7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,
M7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!03%]M96UO<GE?=W)A<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G
M971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E
M:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R
M;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN
M:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T
M<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y
M`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S
M=&1E<G(`9V5T=6ED`')E861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R
M8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T
M<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&0M;&EN=7@M87)M
M:&8N<V\N,P!?7W-T86-K7V-H:U]G=6%R9`!?961A=&$`7U]B<W-?<W1A<G0`
M7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C
M7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE
M`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`
M<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,
M24)#7S(N-`````````````````(``P`"``(``0````(````!``(``@`!``(`
M`0`!``(``@`"``$``@`!``$``0`"``(````"``(``P`#``(``0`"`````@`"
M``,``P`"``$``@`!```````!``$``0`"``$``0````(````"``$``0`"``(`
M``````$````!``$````"``,````````````"`````@`!``$````"``$``@`$
M``$```````$``@`"``(````"``(``@`"``(``0`"`````@`!```````!````
M```!``$`=0,``!`````@````%&EI#0``!`#G!`````````$``0#3`0``$```
M`"`````4:6D-```#`.<$`````````0`!`"("```0`````````!1I:0T```(`
MYP0````````4L0(`%0(``"BQ`@`43```,+$"`!15```XL0(`%$L``#RQ`@`4
M.0``0+$"`!0M``!$L0(`%%T```RP`@`6!P``$+`"`!8%```4L`(`%A@``!BP
M`@`6*@``'+`"`!86```@L`(`%CX``"2P`@`66@``*+`"`!9%```LL`(`%EX`
M`#"P`@`66P``-+`"`!8,```XL`(`%E\``#RP`@`640``0+`"`!9"``!$L`(`
M%C@``$BP`@`6-```3+`"`!9&``!0L`(`%@\``%2P`@`6'```6+`"`!8O``!<
ML`(`%DT``&"P`@`67```9+`"`!9D``!HL`(`%DD``&RP`@`65P``<+`"`!8&
M``!TL`(`%E@``'BP`@`64@``?+`"`!8A``"`L`(`%F$``(2P`@`6%```B+`"
M`!8P``",L`(`%@(``)"P`@`6"```E+`"`!8=``"8L`(`%B,``)RP`@`6:```
MH+`"`!8H``"DL`(`%B(``*BP`@`65```K+`"`!8W``"PL`(`%F```+2P`@`6
M'@``N+`"`!9F``"\L`(`%DX``,"P`@`6:P``Q+`"`!8_``#(L`(`%F4``,RP
M`@`6"@``T+`"`!8E``#4L`(`%D```-BP`@`6"P``W+`"`!9B``#@L`(`%CH`
M`.2P`@`62```Z+`"`!8F``#LL`(`%CT``/"P`@`62@``]+`"`!9I``#XL`(`
M%A$``/RP`@`6#@```+$"`!8G```$L0(`%BD```BQ`@`6'P``#+$"`!85```0
ML0(`%D<```A`+>E'`0#K"("]Z`3@+>4$X)_E#N"/X`CPON5,FP$``,:/XAG*
MC.),^[SE`,:/XAG*C.)$^[SE`,:/XAG*C.(\^[SE`,:/XAG*C.(T^[SE`,:/
MXAG*C.(L^[SE`,:/XAG*C.(D^[SE`,:/XAG*C.(<^[SE`,:/XAG*C.(4^[SE
M`,:/XAG*C.(,^[SE`,:/XAG*C.($^[SE`,:/XAG*C.+\^KSE`,:/XAG*C.+T
M^KSE`,:/XAG*C.+L^KSE`,:/XAG*C.+D^KSE`,:/XAG*C.+<^KSE`,:/XAG*
MC.+4^KSE>$?`1@#&C^(9RHSBR/J\Y0#&C^(9RHSBP/J\Y0#&C^(9RHSBN/J\
MY0#&C^(9RHSBL/J\Y0#&C^(9RHSBJ/J\Y0#&C^(9RHSBH/J\Y0#&C^(9RHSB
MF/J\Y0#&C^(9RHSBD/J\Y0#&C^(9RHSBB/J\Y0#&C^(9RHSB@/J\Y0#&C^(9
MRHSB>/J\Y0#&C^(9RHSB</J\Y0#&C^(9RHSB:/J\Y0#&C^(9RHSB8/J\Y0#&
MC^(9RHSB6/J\Y0#&C^(9RHSB4/J\Y0#&C^(9RHSB2/J\Y0#&C^(9RHSB0/J\
MY0#&C^(9RHSB./J\Y0#&C^(9RHSB,/J\Y0#&C^(9RHSB*/J\Y0#&C^(9RHSB
M(/J\Y0#&C^(9RHSB&/J\Y0#&C^(9RHSB$/J\Y0#&C^(9RHSB"/J\Y7A'P$8`
MQH_B&<J,XOSYO.5X1\!&`,:/XAG*C.+P^;SE`,:/XAG*C.+H^;SE`,:/XAG*
MC.+@^;SE`,:/XAG*C.+8^;SE`,:/XAG*C.+0^;SE`,:/XAG*C.+(^;SE`,:/
MXAG*C.+`^;SE`,:/XAG*C.*X^;SE`,:/XAG*C.*P^;SE`,:/XAG*C.*H^;SE
M`,:/XAG*C.*@^;SE`,:/XAG*C.*8^;SE`,:/XAG*C.*0^;SE`,:/XAG*C.*(
M^;SE`,:/XAG*C.*`^;SE`,:/XAG*C.)X^;SE`,:/XAG*C.)P^;SE`,:/XAG*
MC.)H^;SE`,:/XAG*C.)@^;SE`,:/XAG*C.)8^;SE`,:/XAG*C.)0^;SE`,:/
MXAG*C.)(^;SE`,:/XAG*C.)`^;SE`,:/XAG*C.(X^;SE`````/"U2_(P%\#R
M`@>)L#MH!9`%J`21!*D#D@.J!Y/_]S;O0?+@8L#R`0)!\EAPP/(!`!%&!/!O
M^DOR/!/`\@(#'7@`+7C02_(X%,#R`@0@:/_WT.^0^!XT`D8@:$/P`@."^!XT
M__?&[P6;!3.S\8!/D/@>)$+P`0*`^!XD?=*8`$SR4";_]\CN!)Q+\B`1P/("
M`06:P/("!DEH1O+@`P$JP/(!`P5&(&A&^/!<:V!&\N0#J6#`\@$#3_`$`>M@
M1OCT',B_(QTH8,2_!.N"!`7Q#`$%W5/X!`NC0D'X!`_YT0+Q@$$`)`,Q`)16
M^.@,`S)%^"%`*T9$]@51P/(!`?_W$N\$1FBS5OCH#/_W6NY%]I!@!JG`\@$`
M`O#G_SBS5OCH#/_W*.[_]_+N!YH[:"!&FD(XT0FP\+W_]V+N3/)0(\#R`@-#
M^.@,>+-+\C@4P/("!/_W"NX@:/_W3.^`^(U6=>=6^.@,__<:[P1&R^=6^.P,
M8+$$\*GYT>=+\D011?:\<,#R`@'`\@$`__>8[@:I1?8L8,#R`0`"\*?_1OCL
M#``HO-#FY__W\NT!(/_W9.X`OT_P``M/\``.`KQJ1@2T`;3?^!#`3?@$S0-(
M!$O_]SKN__?V[D%=`0#A%P$`!5T!`!0PG^44()_E`S"/X`(@D^<``%+C'O\O
M`1?__^HPE@$`%`$```=+2_(H$,#R`@`;&@8K!=E`\@`#P/(``P.Q&$=P1P"_
M*[$"`$OR*!-+\B@0P/("`\#R`@`9&HD0`>O1<4D0!=!`\@`#P/(``P.Q&$=P
M1P"_$+5+\E<4P/("!"-X&[G_]\__`2,C<!"]"+5*]OQ@P/("``-H$[F]Z`A`
MT^=`\@`#P/(``P`K]M"81_3G+>GP3TOR,!.M]3]]P/("`P#Q,`8`\7`'&Y,<
MK!MH`"6V1KQ&&I"]DU[X"#\0-`&5&[KF1=[X!!!$^!`\3_```T3X#%Q/Z@$J
M3^H1:T_J$2;-^`"P3^H!80KT?P)"Z@$"W>D``4#J`@!!Z@,!`D8&]']`"T9"
MZ@`"3_```4/J`0-$Z0(CT-$-\6@.#?4:?'%&_ND"9]'I'"/1Z1)%T>D&`6)`
M:T!00%E`1D!/0+(9YD5/ZM9X3_```TCJ1PA"Z@@"SND@(^/1&I\`(@WUN'[7
MZ0`TU^D(`=?I`JNA1IA&3D8`(\WI$`$01AE&<P'-Z0(!0^K88]?I!`'<1M?I
M!F?-Z0J)#_8<==7I`$7-Z09G1T9Z`=WI$(G=Z1QG&D/-Z00!%NL(!D?K"0>P
M1A3K"`2Y1D7K"07=Z09GH$:I1F5&<$!Y0*P'`Y141@KJ``L,Z@$,H`C=Z08T
M&.L""%Y&`YIG1H/J!@.$Z@<$K$9)\0`)'D8G1D+JF@,8ZP8$`Y-31D#JA7!/
MZH-S`I-C1DGK!P69",WI"$4E1MWI`C0`)LWI`%8#0PQ#`)[31AE&`9O-Z1*\
M(D;=Z0:K`"==`<WI#A)%ZM9E`"(`GD_P``C-Z0P2*$;=Z1XCS>D">'0!&NL"
M"MWI"F=+ZP,+($-21@_V-&K:Z0":NP<#DQGK`@G=Z0Q%W>D$(TKK"PI/ZI8+
M3^J7#&)``YQK0#U&1.J6!!U``Y0T1A1`*T9+ZH=[(D;=Z01%5$!=0")&&>L"
M"4_JAG1*ZP4*`I09ZP`$2O$`!4_P``HA1MWI`C0J1LWI%!)#Z@L#1.H,!`A&
M44:;1MWI#B.D1LWI`KR"Z@L(W>D(J]WI($5/ZD$;"NH("MWI!(F"Z@H"`9L8
MZP0(2^K0:TGK!0D61D1&3^I`&DU&#_9X6=GI`(E*Z@L*W>D4O!CK!`A)ZP4)
M&.L&"`">3^J#=4GQ``D8ZPH(2?$`"47JE@4`GLI&P4;-Z0Z:3_``"K0'`9Y7
M1D3J!0FS"$Q&1>H#"MWI`B-&1H+J!`E51H/J!0K-Z0A%3$;=Z2*)"^H$"P_V
M"%75Z0!%#.H*#,WI`+P4ZP@$3^I'&T7K"05+ZM9KH$9/ZD8:J4;=Z0!%2NH+
M"@`E5$#=Z0PC$NL(`D/K"0.01ACK!`A#\0`)`"3-Z0!%&.L*!$_J@7,!DZ!&
M`9Q)\0`%BPA$ZI`$`92I1@`E(D:$!P"4*4;=Z0!%0$;-Z12)'4/=Z22)%$/=
MZ0@CK$:J1J-&@^H*!<WI#+R"Z@L$W>D.JP*;"NH$"@OJ!0L/]EQ%U>D`1<WI
M`*M/ZD$;%.L(!$OJT&M%ZPD%3^I`&J!&&.L#"*E&W>D`14KJ"PI)\0`)5$"]
M!QCK!`A%ZI8%2?$`"1CK"@))\0`#`)611K0'FD:["`&3%D;=Z0`CS>D.FD_P
M``HB0RM#5T;=Z2:)FT:21MWI#"/<1LWI`JN"Z@H$W>D4JX/J#`4(FPKJ!`H+
MZ@4+#_;(-=7I`$7-Z0"K3^I'&Q3K"`1+ZM9K1>L)!4_J1AJ@1ACK`PBI1MWI
M`$5*Z@L*2?$`"51``"48ZP0(3_``!$GQ``G-Z0!%&.L*!$_J@7,!DTGQ``6@
M1@&<J48`)43JD`0!E(L(*48B1H0'`)1`1MWI`$7-Z12)'4,40]WI`B.C1JQ&
M@NH+!,WI"+RJ1H/J"@7=Z0ZKW>DHB0KJ!`H+Z@4+#_8D-=7I`$7-Z0"K3^I!
M&Q3K"`0,FT7K"05+ZM!KH$9/ZD`:J4;=Z0!%&.L#"$KJ"PJ$Z@($2?$`"1CK
M!`A/ZH=U2?$`"1CK"@))\0`#1>J6!0"5D4::1KL(`9.T!Q9&W>D`(\WI#II/
M\``*(D,K0U=&W>DJB9M&DD;=Z0@CW$;-Z0RK@NH*!-WI%*N#Z@P%`IL*Z@0*
M"^H%"P_VC"75Z0!%S>D`JT_J1QL4ZP@$2^K6:T7K"05/ZD8:H$88ZP,(J4;=
MZ0!%2NH+"DGQ``E40``E&.L$"$_P``1)\0`)S>D`11CK"@1/ZH%S`9-)\0`%
MH$8!G*E&`"5$ZI`$`92+""E&(D:$!P"40$;=Z0!%S>D4B1U#%$/=Z0PCHT:L
M1H+J"P3-Z0*\JD:#Z@H%W>D.J]WI+(D*Z@0*"^H%"P_VZ!75Z0!%S>D`JT_J
M01L4ZP@$")M%ZPD%2^K0:Z!&3^I`&JE&W>D`11CK`PA*Z@L*A.H"!$GQ``D8
MZP0(3^J'=4GQ``D8ZPH"2?$``T7JE@4`E9%&FD:["`&3M`<61MWI`"/-Z0Z:
M3_``"B)#*T-71MWI+HF;1I)&W>D"(]Q&S>D(JX+J"@3=Z12K@^H,!0KJ!`H+
MZ@4+#_90%=7I`$7-Z0"K3^I'&Q3K"`0,FT7K"05+ZM9KH$9/ZD8:J4;=Z0!%
M&.L#"$KJ"PJ$Z@($2?$`"1CK!`A/\``%2?$`"0`DS>D`11CK"@1/ZH%S`9.@
M1@&<2?$`!8L(1.J0!`&4J48`)2)&A`<`E"E&W>D`14!&S>D4B1U#%$/=Z0@C
MHT:L1H+J"P3-Z0R\JD:#Z@H%W>D.J]WI,(D*Z@0*"^H%"P_VK`75Z0!%S>D`
MJT_J01L4ZP@$`IM%ZPD%2^K0:Z!&3^I`&JE&W>D`11CK`PA*Z@L*A.H"!$GQ
M``D8ZP0(3^J'=4GQ``D8ZPH"2?$``T7JE@4`E9%&FD:["`&3M`<61MWI`"/-
MZ0Z:3_``"B)#*T-71MWI,HF;1I)&W>D,(]Q&S>D"JX+J"@3=Z12K@^H,!0B;
M"NH$"@OJ!0L/]A`%U>D`1<WI`*M/ZD<;%.L(!$OJUFM%ZPD%3^I&&J!&&.L#
M"*E&W>D`14KJ"PI)\0`)5$``)1CK!`A/\``$2?$`"<WI`$48ZPH$3^J!<P&3
M2?$`!:!&`9RI1@`E1.J0!(L(`90I1B)&A`<`E$!&S>D4B=WI`$7=Z32)'4,4
M0]WI`B.C1JQ&@NH+!,WI"+RJ1H/J"@7=Z0ZK#)L*Z@0*"^H%"P_R;'75Z0!%
MS>D`JT_J01L4ZP@$2^K0:T7K"05/ZD`:H$88ZP,(J4;=Z0!%2NH+"DGQ``E4
M0+T'&.L$"$7JE@5)\0`)&.L*`DGQ``,`E9%&M`>:1KL(`9,61MWI`"/-Z0Z:
M3_``"B)#*T-71MWI-HF;1I)&W>D((]Q&S>D,JX+J"@3=Z12K@^H,!0*;"NH$
M"@OJ!0L/\MAEU>D`1<WI`*M/ZD<;%.L(!$OJUFM%ZPD%3^I&&J!&&.L#"*E&
MW>D`14KJ"PI)\0`)5$``)1CK!`A/\``$2?$`"<WI`$48ZPH$3^J!<P&32?$`
M!:!&`9RI1@`E1.J0!`&4BP@I1B)&A`<`E$!&W>D`1<WI%(D=0Q1#W>D,(Z-&
MK$:"Z@L$S>D"O*I&@^H*!=WI#JO=Z3B)"NH$"@OJ!0L/\CAEU>D`1<WI`*M/
MZD$;%.L(!$OJT&M%ZPD%3^I`&J!&2NH+"JE&W>D`10B;O0=40$7JE@48ZP,(
M`)5)\0`)&.L$"$GQ``D8ZPH"2?$``[0'D4861II&NP@!D]WI`"/-Z0Z:3_``
M"B)#*T-71MWI.HF;1I)&W>D"(]Q&S>D(JX+J"@3=Z12K@^H,!0R;"NH$"@OJ
M!0L/\J!5U>D`1<WI`*M/ZD<;%.L(!$OJUFM%ZPD%3^I&&J!&&.L#"*E&W>D`
M14KJ"PI)\0`)5$``)1CK!`A/\``$2?$`"<WI`$48ZPH$3^J!<P&32?$`!:!&
M`9RI1@`E1.J0!`&4BP@I1B)&A`<`E$!&W>D`1<WI%(D=0Q1#W>D((Z-&K$:"
MZ@L$S>D,O*I&@^H*!=WI#JO=Z3R)"NH$"@OJ!0L/\@!5U>D`1<WI`*M/ZD$;
M%.L(!`*;1>L)!4OJT&N@1D_J0!JI1MWI`$48ZP,(2NH+"H3J`@1)\0`)&.L$
M"$_JAW5)\0`)&.L*`DGQ``-%ZI8%`)611II&NP@!D[0'%D;=Z0`CS>D.FD_P
M``HB0RM#5T;=Z3Z)FT:21MWI#"/<1LWI`JN"Z@H$W>D4JX/J#`4(FPKJ!`H+
MZ@4+#_)D1=7I`$7-Z0"K3^I'&Q3K"`1+ZM9K1>L)!4_J1AJ@1ACK`PBI1MWI
M`$5*Z@L*2?$`"51``"48ZP0(3_``!$GQ``G-Z0!%&.L*!$_J@7,!DTGQ``6@
M1@&<J48`)43JD`0!E(L(*48B1H0'`)1`1MWI`$7-Z12)'4-`JQ1#T^D`B:Q&
M^*/3Z0`CHT;=Z0)%O0<2ZP@"S>D(O(3J"P1#ZPD#W>D.JY!&F4;=Z0(C"NH$
M"@R;3^I!&T7JE@541F)`2^K0:QCK`PA/ZD`:%$9*Z@L*2?$`"1CK!`@`E4GQ
M``D8ZPH"2?$``[0'D$:11II&NP@!D]WI`"/-Z0Z:3_``"B)#*T/=Z0A6T4:2
M1IM&A>H*!4*KS>D,JT_J21LN1MWI%$73Z0`C2^K8:S1`3^I(&B9&S:75Z0!%
MI!A=02)&`"0K1@`ES>D`14_JV&0`E-WI"$7-^`"P=$`F1@*<$AE/ZMED0_$`
M`P&4E!E#\0`%)D;=Z0`TA`=#Z@H#]AA/ZI$#1?$`!XT'1*E%ZI`%1.H%`+-&
MO$;-Z12\T>D`JT7J`P'=Z0Q%`D8+1LWI`"/=Z0X21$!/\``,<@%A0&=&>P$,
M1JNAT>D``4/JUF,0ZPH`0NH#`D'K"P%/ZID#BT8(F1#K`0I/ZHEQ2_$`"QKK
M!`I!ZI@!2_$`"QKK`@1/\``*2_$`!4_JB'#-Z0Y%549!Z@,*1JM`Z@$)W>D`
M$LWI`IK3Z0"K@>H)`=WI%"-K`4/JU&-*0(^AT>D``1#K"@"01D'K"P%B`1I#
MNPB+1@R9$.L!"D_JAW%+\0`+&NL("DOQ``L:ZP((2_$`"4'JE@'#1K`'S$9>
M1LWI#+Q`Z@$+0>H##-WI`A)(J\WI"+R!Z@L!3_``"-/I`*M'1MWI#B-[`4/J
MUF-*0'*AT>D``1#K"@"01D'K"P%R`1I#JPB+1@"9$.L!"D_JA7%+\0`+&NL(
M"DOQ``L:ZP((2_$`"4'JE`&@!T1&RD;!1LWI#II!Z@,*W>D((TJK0.H!"5VA
MT>D``<WI`)J"Z@D"T^D`JP`ED$;=Z0PC$.L*`$_J11-!ZPL!@NH(`D/JU&.+
M1@*9D$9B`1#K`0I/ZH=Q0>J6`4+J`P)/ZH9P2_$`"QKK"`I/ZI<#2_$`"QKK
M`@A`Z@$*2_$`"4'J`PO-Z0R)44;=Z0":6D;-Z0(2B>H!"=WI#A),JT=&@>H)
M`4_P``@^1M/I`*M'1HA&-Z'1Z0`!>P%#ZM9C<@$0ZPH`0NH#`D'K"P&K"(M&
M")D0ZP$*3^J%<4OQ``L:ZP@*2_$`"QKK`@A+\0`)0>J4`:`'PT;,1LWI#KQ`
MZ@$+0>H##-WI`A).J\WI"+P`)8'J"P'3Z0"KW>D,(T1&:P%*0!NAT>D``4/J
MU&,0ZPH`D$9!ZPL!8@$:0[L(BT8`F1#K`0I/ZH=Q2_$`"QKK"`I+\0`+&NL"
M"$OQ``E!ZI8!L`=!Z@,+RD;!1LWI#)I/\``*5T9`Z@$*4*M:1E%&W>D(FLWI
M`!)&1@?@F7F"6@````"AZ]EN`````-/I`*N)Z@$)#_8,<='I``'=Z0XC>P$0
MZPH`0^K68T'K"P&"Z@D"BT8"F9!&<@$0ZP$*0NH#`DOQ``NI!QKK"`I!ZI0!
M2_$`"Z`'&NL""$_JE0-+\0`)0>H##$#J`0M2J]WI`!(`)<WI`KQ$1H'J"P'3
MZ0"KW>D,(VL!S>D.B4/JU&-*0`_VD&'1Z0`!$.L*`)!&0>L+`6(!&D.["(M&
M")D0ZP$*3^J'<4OQ``L:ZP@*2_$`"QKK`@A+\0`)0>J6`;`'0>H#"\I&P4;-
MZ0R:3_``"E=&0.H!"E2K6D911MWI`IK-Z0@21D;3Z0"KB>H!"0_V)&'1Z0`!
MW>D.(WL!$.L*`$/JUF-!ZPL!@NH)`HM&`)F01G(!$.L!"D+J`P)+\0`+J0<:
MZP@*0>J4`4OQ``N@!QKK`@A/ZI4#2_$`"4'J`PQ`Z@$+5JO=Z0@2`"7-Z0"\
M1$:!Z@L!T^D`J]WI#"-K`<WI#HE#ZM1C2D`/]JA1T>D``1#K"@"01D'K"P%B
M`1I#NPB+1@*9$.L!"D_JAW%+\0`+&NL("DOQ``L:ZP((2_$`"4'JE@&P!T'J
M`PO*1L%&S>D,FD_P``I71D#J`0I8JUI&44;=Z0":S>D"$D9&T^D`JXGJ`0D/
M]CQ1T>D``=WI#B-[`1#K"@!#ZM9C0>L+`8+J"0*+1@B9D$9R`1#K`0I/ZH5Q
M0>J4`4+J`P)/ZI4#2_$`"T'J`PP:ZP@*6JM+\0`+H`<:ZP((2_$`"4#J`0O3
MZ0`!1$;=Z0(C`"7-Z0B\@NH+`@_VT$O;Z0"KS>D.B1KK``J01MWI#"-+ZP$+
M`)EK`8+J"`)#ZM1C&NL!"D_JAW&01DOQ``L:ZP@*WND`B4_J1!)+\0`+&D-!
MZI8!S>D`B1KK`@A+\0`)L`>["`WUO'[*1L%&3D;-Z12:0.H!"4'J`PK=Z0@2
M3_``"$=&S>D,F@_V4$/3Z0`C@>H)`=WI`(D8ZP((2>L#"0*;S$;=Z0Z:&.L#
M"D_J1AB)Z@$)3/$`"ZD'2$9/ZD<92>K6:1KK``I(Z@D(2_$`"QKK"`)!ZI0!
M2_$``P"1H`>L"`&4D$841IE&W>D`(P`ES>D.B4_J11L"0PM#WND`B4OJU&L0
M1AE&W>D,(T_J1!K-Z0(!#?7`?D)`#_;`,='I``$(FQ#K"`!!ZPD!@$88ZP,(
MB4;=Z10!2?$`"0`C4$``(LWI`",8ZP`"3^K48P"32?$``\WX`+`01D_JAWD9
M1NL.`9-)ZI8)W>D`(T_JAGA"Z@H"2.H)"A#K`@M!\0`,N0A:1DGJ`0MC1M[I
M`&?<1M-&W>D"F@WUQ'[-Z10C`"/-Z0B\B>H+"8KJ#`K-Z1::#_8H.MKI`)I9
M`=WI#KQ!ZM)A&>L&"0&1W>D6`4KK!PH,F58!@.H+`%=&&>L!"@"6@$9'\0`+
M&NL(!D_JTF!+\0`'W>D`JT#J0Q"I"$KJ``H6ZPH(3^J$=D?Q``FO!T?JE`?-
MZ0")1NH'"D?J`0O=Z0@!1$961M[I`(E?1G!`S>D,9P`E#_:D)]?I`&=/ZD4;
M`IE+ZM1K%NL(!D_J1!I'ZPD'#?7(?K!&&.L!"+E&W>D49TGQ``F?!T9`2^H*
M`!CK!@A'ZI('2?$`"1CK``M)\0`,E@>9"%I&V4;B1D;J!PO-Z0Z:1^H!#-[I
M`(D/]CPGU^D`9UA&84;=Z0R\%NL(!D_P``-'ZPD'B^H`"\WI`@&P1@B9N4;=
MZ0!G6$9/ZD,;&.L!"$OJTFN&Z@`&3^I"&DGQ``E*Z@L*&.L&"$GQ``D8ZPH&
M2?$`!ZD(L4:N!T;JE`8!EKI&#?7,?C!&I@<`EDQ&W>D`9P`ES>D4FD_J11L&
M0P]#W>D"`4OJU&O>Z0")3^I$&LWI"&=P0`_VH!?7Z0!G#?70?@R9%NL(!D?K
M"0>P1ACK`0BY1MWI#F=)\0`)GP=&0$OJ"@`8ZP8(1^J2!TGQ``D8ZP`+3^J"
M=D_JDP%:1DGQ``Q&Z@<*WND`B<WI%KQ'Z@$+#_9$%]?I`&<`(UE&W>D(O!;K
M"`901D?K"0>+Z@H+S>D.`;!&N4;=Z11G`IE81D_J0QM&0$OJTFL8ZP$(3^I"
M&DGQ``E*Z@L*&.L&"$GQ``D8ZPH`2?$``:\'1^J4!P"7BD:I"`&1@4:F!P1&
MW>D``0WUU'[-Z12:`"4P0SE#W>D.9T_J11G>Z0"K2>K4:<WI#`%&0$]`#_:L
M`='I``%/ZD08$.L*`$'K"P'=Z1:\S>D``8OJ!@N,Z@<,")E)Z@@&S>D"O-WI
M`*L:ZP$*`IE+\0`+S>D`JT_J@WM/ZH)ZCD;=Z0`!2^J2"Q#K#@!*Z@L"0?$`
M`<WI``'=Z0")F0@`(PWU$GX8ZP8(;*Y)\0`)S>D6B9E&2^H!`]WI#+P11LWI
M`B-+Z@$+3.H##-WI#`%:1MWI%*O6Z0!G"^H,"PKJ`@I;1MWI`KQ21@#J"P`/
M]@`+V^D`JP'J#`$:ZP8*2^L'"U9&0.H""E]&0>H#"PZ93^I)$\WI`*M#ZMAC
M%NL!"@"93^I($D?Q``L:0QKK`0I/\```3_```4OQ``L&1@]&S>D`9Z8(`)8:
MZP(&3^J%<4_JE0)!ZI0!-49/ZH1PJD8`D6ZK`9+=Z0!%2_$`!\WI#F<`)@1#
M#4/3Z0`!LT;=Z18C)D8O1LWI"&?-Z10!3^I+%]WI`@%'ZMIG!$8T0R)`3^I*
M%A1&W>D((Q!`&4`/\D!ST^D`(\WI``'=Z10!@!A900)&"T;=Z0`!`)=/ZHEQ
M($,,G$'JF`$2&4/Q``,4&$/Q``5/ZMMC`9-/ZHAPS>D,14_JF0/=Z0!%0.H!
M"$'J`PDT0]WI#&=`1DE&-AEPK$?Q``?-Z0P!U.D`B35&/D;-Z116`";-Z0")
M-T;=Z0B)+D;=Z0Y%0D9+1@)#"T,40!U`".H`"`GJ`0DB1BM&0$8/\IQEU>D`
M14E&W>D`B1CK!`A)ZP4)1$9`Z@((349!Z@,)`IE[`<WI`(E#ZM9C%.L!"`"9
M3^I&$D7Q``D:0QCK`0A/\```3_```4GQ``D$1@U&<JO-Z0!%3^J+<4_JF@0`
ME!CK`@1!ZIH!3^J;`@"1`9*@1DGQ``7-Z0Y%W>D`14_JBG#3Z0`C3_``"@1#
M#4/=Z0P!T4;-Z18C`"(`(\WI`"-/ZDH3`9/=Z10CHT9`Z@L$K$8B0,WI`KRY
M!Q1&6D8/\MQ;V^D`JQ!`W>D6(R!#")Q!ZI8!$NL*`D/K"P.;1@&;0^K88P&3
M$QE+\0`$FD8:ZP`"HT9/ZD@3`)-+\0`#3^K89))&FT;=Z0`C1.I)%+`'(D.[
M"!KK`@I/\``&-T9+\0`+5D;-Z12K=*Q`Z@$*0>H#"U!&64;4Z0"KW>D.1<WI
M"`'-Z0"KW>D"O%I&8T8"0PM#%$`=0`OJ``L,Z@$,(D8K1EA&#_(X5=7I`$7=
MZ0"K#)D:ZP0*2^L%"U1&0.H""EU&3.H#"\WI`*M[`13K`0H`F4/JUF-/ZD82
M1?$`"QI#&NL!"D_P``!/\``!=JM+\0`+!$8-1D_JB7'-Z0!%3^J8!`"4&NL"
M!$'JF`%/ZID"`)%+\0`%`9)/ZHAPT^D`(Z!&S>D.14_P``K=Z0!%T4;-Z18C
M`"($0PU#W>D(`0`CS>D`(T_J21,!DZ)&W>D4(T#J"@2K1LWI#*LB0+D'0>J6
M`11&4D8/\G1+V^D`JQ!`W>D6(R!#`IP2ZPH"0^L+`YM&`9M#ZMAC`9,3&4OQ
M``2:1AKK``*C1D_J2!,`DTOQ``-/ZMADDD:;1MWI`"-$ZDD4L`<B0[L(&NL"
M"D_P``8W1DOQ``M61LWI%*MXK$#J`0I!Z@,+4$991M3I`*O=Z0Y%S>D"`<WI
M`*O=Z0R\6D9C1@)#"T,40!U`"^H`"PSJ`0PB1BM&6$;UI=7I`$7=Z0"K")D:
MZP0*2^L%"U1&0.H""EU&3.H#"\WI`*M[`13K`0H`F4/JUF-/ZD821?$`"QI#
M&NL!"D_P``!/\``!2_$`"P1&#49ZJ\WI`$5/ZHEQ3^J8!`"4&NL"!$'JF`%/
MZID"`)%+\0`%`9)/ZHAPT^D`(Z!&S>D.14_P``K=Z0!%T4;-Z18C`"($0PU#
MW>D"`0`CS>D`(T_J21,!DZ)&W>D4(T#J"@2K1LWI"*LB0+D'0>J6`11&4D8/
M\A0[V^D`JQ!`W>D6(R!##)P2ZPH"0^L+`YM&`9M#ZMAC`9,3&4OQ``2:1AKK
M``*C1D_J2!,`DTOQ``-/ZMADDD:;1MWI`"-$ZDD4L`<B0[L(&NL""D_P``8W
M1DOQ``M61LWI%*M\K$#J`0I!Z@,+4$991M3I`*O=Z0Y%S>D,`<WI`*O=Z0B\
M6D9C1@)#"T,40!U`"^H`"PSJ`0PB1BM&6$:<I=7I`$7=Z0"K`ID:ZP0*2^L%
M"U1&0.H""EU&3.H#"\WI`*M[`13K`0H`F4/JUF-/ZD821?$`"QI#&NL!"D_P
M``!/\``!2_$`"P1&#49/ZHEQS>D`14_JF`0`E!KK`@1!ZI@!3^J9`@"1`9)+
M\0`%3^J(<,WI%D6@1MWI`$5^JT_P``H$0]%&#4/=Z0P!HD;3Z0`T`"*K1LWI
M#JNY!\WI`C0`(\WI`"-/ZDD3`9-`Z@H$W>D4(T'JE@$B0!1&4D;=Z0*K$$!K
MH]/I`",@0QKK`@I+ZP,+`9L(G$/JV&,!DQKK!`)/ZMAD2_$``Q(81.I)%$_J
MAG";1D_J2!,`DTOQ``.31@`FG$;=Z0`CNP@B0T#J`00;ZP(+3/$`#,WI%+Q=
M1LWI`%9!Z@,%@*G=Z1:\(D;1Z0`!*T8!G@"?S>D8`=WI#@%V`<WI""-&ZM=F
M0.H"!!!`"^H$"]WI&",#EGX!7$8/\A`<W.D`O"!##)P2ZPL"`I9#ZPP#`9X2
M&4_JB7%#\0`#$NL`"T/Q``S\#MWI`B-!ZI@!1.I&%$_JB'!/ZID#(D-!Z@,%
M0.H!!(*I&^L""T_P``E/\``"T>D``4_P``/-Z0(C3^I)$P.3V$8&1@]&W>D(
M`4SQ``S=Z10CS>D6O*-&0.H+!*Q&(D#-Z0R\%$9:1@_R?`S<Z0"\$$`@0PZ<
M%NL+`@.>1^L,`Q(91NK89D/Q``,#EA+K``M/ZD@6`I9#\0`,W>D"(P&>3^K8
M9$3J210B0P&<L0<`GAOK`@M/\``"3^J4`TSQ``Q!ZI8!L`=`Z@$$748`)LWI
M`%9!Z@,%A*D`(PG@K_,`@*'KV6X`````W+P;CP````#-Z0(CT>D``0&;S>D4
MO*-&!D8/1MWI#`%;`0.3K$;=Z18C0.H+!,WI#KQ/ZHEQ(D!!ZI@!%$9:1@_V
MM&S<Z0"\$$`@0PB<%NL+`@.>1^L,`P"?$AE#\0`#$NL`"T;JUV8#ED_J1Q8"
ME@&>0_$`#/P.W>D"(T_JB'!/ZID#1.I&%$'J`P4B0T#J`02&J1OK`@M/\``)
M3_```M'I``%/\``#S>D"(T_J21,#D]A&!D8/1MWI#@%,\0`,W>D4(\WI%KRC
M1D#J"P2L1B)`S>D(O!1&6D8/]AQLW.D`O!!`($,,G!;K"P(#GD?K#`,2&4;J
MV&9#\0`#`Y82ZP`+3^I(%@*6`9Y#\0`,3^K89-WI`B-$ZDD4(D.Q!P">&^L"
M"P&<3_```EU&3/$`#$'JE@&P!Z,(`"9`Z@$$S>D`5D'J`P6(J0`CS>D"(]'I
M``$!F\WI%+RC1@9&#T;=Z0@!6P$#DZQ&W>D6(T#J"P3-Z0R\3^J)<2)`0>J8
M`11&6D8/]G1<W.D`O!!`($,.G!;K"P(#GD?K#`,`GQ(90_$``Q+K``M&ZM=F
M`Y9/ZD<6`I8!GD/Q``S\#MWI`B-/ZHAP3^J9`T3J1A1!Z@,%(D-`Z@$$BJD;
MZP(+3_``"4_P``+1Z0`!3_```\WI`B-/ZDD3`Y/81@9&#T;=Z0P!3/$`#-WI
M%"/-Z1:\HT9`Z@L$K$8B0,WI#KP41EI&#_;83-SI`+P00"!#")P6ZPL"`YY'
MZPP#$AE&ZMAF0_$``P.6$NL`"T_J2!8"E@&>0_$`#$_JV&3=Z0(C1.I)%")#
ML0<`GAOK`@L!G$_P``)=1DSQ``Q!ZI8!L`>C"``F0.H!!,WI`%9!Z@,%C*D`
M(\WI`B/1Z0`!`9O-Z12\HT8&1@]&W>D.`5L!`Y.L1MWI%B-`Z@L$S>D(O$_J
MB7$B0$'JF`$41EI&#_8P3-SI`+P00"!##)P6ZPL"`YY'ZPP#`)\2&4/Q``,2
MZP`+1NK79@.63^I'%@*6`9Y#\0`,_`[=Z0(C3^J(<$_JF0-$ZD840>H#!2)#
M0.H!!(ZI&^L""T_P``E/\``"T>D``4_P``/-Z0(C3^I)$P.3V$8&1@]&W>D(
M`4SQ``S=Z10CS>D6O*-&0.H+!*Q&(D#-Z0R\%$9:1@_VF#S<Z0"\$$`@0PZ<
M%NL+`@.>1^L,`Q(91NK89D/Q``,#EA+K``M/ZD@6`I8!GD/Q``Q/ZMADW>D"
M(T3J210B0[$'`9P;ZP(+`)Y,\0`,S>D.O*,(0>J6`;`'0.H!!$'J`P60J0`F
M-T9>1M'I`*LB1MWI#`$`(ZQ&3^J)<<WI%*M`Z@($DT8`(LWI`"-[`0&30>J8
M`=WI%B/-Z0*\(D`41EI&W>D4JQ!`#_;L(]/I`",@0PB<&NL""DOK`PL!FQKK
M!`)/ZM9D0^K68P&32_$``Q(81.I'%$_JB'";1D_J1A,`DTOQ``.21IM&W>D`
M(T_JF0-/\``)(D,:ZP(*2_$`"U1&T$9=1LWI%$5!Z@,%0.H!!-WI`KQ/ZD@0
M(48J1M[I`$7-Z0@2S>D6165&%4/=Z0XC7$8,0R)`*T#-Z0`C3^I)$=WI""-!
MZMAAW>D610OJ`@H/]D0CT^D`(Z0874$B1BM&S>D.(]WI`#0,1@1#N0A#Z@H#
MFD8,FYY&W>D.(Q+K#@)#\0`#$NL*`D/Q``,2ZP0*0_$`"[L'0^J6`U1&748!
MD\WI#D6T!P"4&$;=Z0!G`"-=`5)&!D,/0]WI"`%%ZMIES>D,9U0!W>D4O'E`
M<$`N1HSJ`0R4J8OJ``O-Z0"\T>D`JR9##_:X$='I``'=^/3B&NL`"DOK`0L"
MF1KK`0H`F4OQ``L:ZP$*3^J9`4OQ``L:ZP8$3^J)=DOQ``5&ZI@&`9;-Z11%
M,$8`)C=&)D9/ZHAT`)3=Z0!%W>D,F@1##4,`(``AS>D``7D!`9&6J:-&K$:)
MZ@0)S>D"O-'I`$7P#@_V/!O;Z0"K0.I'$`&9%.L*!$7K"P7=Z0Z\0>K680&1
M")F+Z@D+%.L!"MA&3^I&%$7Q``L`E!KK"`1+\0`%W>D`O)D(#?4<?*I&G0=+
MZ@`+1>J2!0`C%.L+"9M&1>H!`T_J@G1*\0`*1.H%`LWI#IK*1IE&W>D"-)BI
MD$;-Z0")4T#1Z0`!3^I*$IA&#_:P!-3I`#0;&$_JAG!,02%&W>D4183J"`2@
M1@R<'!E/ZDL30^K:8T'Q``4:0Q3K"`1%\0`%N0<4ZP((0>J6`4_JEP-%\0`)
M1$9`Z@$'0>H#")JI/D9-1D=&T>D`B=WI`!+=Z0XC<4#-Z0Q%2D``)<WI"&=O
M`1!&#_8X`]/I`"-'ZM1G9@$2ZP@"3^J+<4/K"0-!ZIH!F48"FQ+K`P@Z1DGQ
M``DR0QCK``A/ZIL#2?$`"1CK`@9)\0`'3^J*<$_P``JQ1KA&-T;-Z0YX0.H!
M!T'J`PC31CI&W.D``4-&W>D(>+)&S>D"(U=`W>D,(T_J2Q,-]2!\N$8/\KAW
MU^D`9X+J"`)#ZMEC-AA/ZH1P3T&01D_J21(Y1@"?&D.K"/890?$`!Q;K"`9'
M\0`'J0<6ZP((0>J4`4?Q``E`Z@$'S>D,B41&0>H#")ZI/D8`)4=&T>D`B=WI
M`A+=Z0XC<4#-Z0!G2D!O`4?JU&=F`1!&#_)`<]/I`"-/ZHMQ$NL(`D'JF@%#
MZPD#F48(FQ+K`P@Z1DGQ``DR0QCK``A/ZIL#2?$`"1CK`@9)\0`'3^J*<$_P
M``JQ1KA&-T;-Z0YX0.H!!T'J`PC31CI&W.D``4-&W>D`>+)&S>D((U=`W>D,
M(T_J2Q,-]21\N$8/\LAGU^D`9X+J"`)#ZMEC-AA/ZH1P3T&01D_J21(Y1@*?
M&D.K"/890?$`!Q;K"`9'\0`'J0<6ZP((0>J4`4?Q``E`Z@$'1$;-Z0R)0>H#
M"**I/D8`)4=&T>D`B=WI"!+=Z0XC<4#-Z0)G2D!O`4?JU&=F`1!&#_)08]/I
M`"-/ZHMQ$NL(`D'JF@%#ZPD#F48`FQ+K`P@Z1DGQ``DR0QCK``A/ZIL#2?$`
M"1CK`@9)\0`'3^J*<$_P``JQ1KA&-T;-Z0YX0.H!!T'J`PC31CI&W.D``4-&
MW>D">+)&S>D`(U=`W>D,(T_J2Q,-]2A\N$8/\MA7U^D`9X+J"`)#ZMEC-AA/
MZH1P3T&01D_J21(Y1@B?&D.K"/890?$`!Q;K"`9'\0`'J0<6ZP((0>J4`4?Q
M``E`Z@$'1$;-Z0R)0>H#"*:I/D8`)4=&T>D`B=WI`!+=Z0XC<4#-Z0AG2D!O
M`4?JU&=F`1!&#_)@4]/I`"-/ZHMQ$NL(`D'JF@%#ZPD#F48"FQ+K`P@Z1DGQ
M``DR0QCK``A/ZIL#2?$`"1CK`@9)\0`'3^J*<$_P``JQ1KA&-T;-Z0YX0.H!
M!T'J`PC31CI&W.D``4-&W>D(>+)&S>D"(U=`W>D,(T_J2Q,-]2Q\N$8/\NA'
MU^D`9X+J"`)#ZMEC-AA/ZH1P3T&01D_J21(Y1@"?&D.K"/890?$`!Q;K"`9'
M\0`'J0<6ZP((0>J4`4?Q``E`Z@$'1$;-Z0R)0>H#"*JI/D8`)4=&T>D`B=WI
M`A+=Z0XC<4#-Z0!G2D!O`4?JU&=F`1!&#_)P0]/I`"-/ZHMQ$NL(`D'JF@%#
MZPD#F48(FQ+K`P@Z1DGQ``DR0QCK``A/ZIL#2?$`"1CK`@9)\0`'3^J*<$_P
M``JQ1KA&-T;-Z0YX0.H!!T'J`PC31CI&W.D``4-&W>D`>+)&S>D((U=`W>D,
M(T_J2Q,-]3!\N$;^I]?I`&>"Z@@"0^K98S883^J$<$]!D$9/ZDD2.48"GQI#
MJPCV&4'Q``<6ZP@&1_$`!ZD'%NL""$'JE`%'\0`)0.H!!T1&S>D,B4'J`PBN
MJ3Y&`"5'1M'I`(G=Z0@2W>D.(W%`S>D"9TI`;P%'ZM1G9@$01N&CT^D`(T_J
MBW$2ZP@"0>J:`4/K"0.91@";$NL#"#I&2?$`"3)#&.L`"$_JFP-)\0`)&.L"
M!DGQ``=/ZHIP3_``"K%&N$8W1LWI#GA`Z@$'0>H#"--&.D;<Z0`!0T;=Z0)X
MLD;-Z0`C5T#=Z0PC3^I+$PWU-'RX1L.GU^D`9X+J"`)#ZMEC-AA/ZH1P3T&0
M1D_J21(Y1@B?&D.K"/890?$`!Q;K"`9'\0`'J0<6ZP((0>J4`4?Q``E`Z@$'
MS>D,B41&0>H#"+*I/D8`)4=&T>D`B=WI`!+=Z0XC<4#-Z0AG2D!O`4?JU&=F
M`1!&IJ/3Z0`C3^J+<1+K"`)!ZIH!0^L)`YE&`IL2ZP,(.D9)\0`),D,8ZP`(
M3^J;`TGQ``D8ZP(&2?$`!T_JBG!/\``*L4:X1C=&S>D.>$#J`0=!Z@,(TT8Z
M1MSI``%#1MWI"'BR1LWI`B-70-WI#"-/ZDL3#?4X?+A&B*?7Z0!G@NH(`D/J
MV6,V&$_JA'!/09!&3^I)$CE&`)\:0ZL(]AE!\0`'%NL(!D?Q``>I!Q;K`@A!
MZI0!1_$`"4#J`0?-Z0")1$9!Z@,(MJD^1@`E1T;1Z0")W>D"$MWI#B-Q0,WI
M#&=*0&\!1^K49V8!$$9KH]/I`"-/ZHMQ$NL(`D'JF@%#ZPD#F48(FQ+K`P@Z
M1DGQ``DR0QCK``A/ZIL#2?$`"1CK`@9)\0`'3^J*<$_P``JQ1KA&-T;-Z0YX
M0.H!!T'J`PC31CI&W.D``4-&W>D,>,WI"".R1E=`W>D`(T_J2Q.I![A&3:?7
MZ0!G@NH(`@*?-AA#ZMECD$;V&4_J21)!ZI0!&D,6ZP@&JP@`)[880>H#":`'
M`"(`([JMS>D`(WL!`9-`Z@$(W>D((P`GU>D`18+J"`*#Z@D#S>D"B0_RW`G9
MZ0")S>D4(P&;&.L$"$GK!0E#ZM9C0$9)1@&3W>D.B1Q&W>D4(X/J"0."Z@@"
MF48,FY!&S>D.B4_JBWE/ZHIXG$80ZPP"0?$``W$!`)%)ZIH)#IG=Z0:K4AC=
MZ0`!0_$``\WI#",@0]WI#$5)Z@@"W>D0B208W>D*`0`A`"4`&1J<3_``"<3I
M``$;F0MHW>D2`0*9@!D:ZP$*")D&1ACK`0C=Z00!5$8`(8`8&IJ>1<+I`F?"
MZ09%PND(B<+I!`$#T0WU/WV]Z/"/_/=>[@"_K_,`@-R\&X\`````UL%BR@``
M````*#S0+>GX0TOR*!/`\@(#T_@`D+GQ``\NT`5X`"T8OSTM%+\!)0`E%='9
M^`!`?+&`1@]&3D8J1D%&($;\]T;O$+EC73TK#]!6^`1/`"SRT2!&O>CX@P5&
M%?@!/P`K&+\]*_G1+1K@YZ;K"09H'"!$MA`^8+WH^(-(1KWH^(-P1W"U2_(P
M%<#R`@6"L$OR*!;`\@(&*V@$1@&3:48@1O_WK_^@L0"8,6@!ZX`#6FA!^"`@
M`"KQT`0S6FA#^`0K`"KZT6E&($;_]YO_`"CJT0&:*VB:0@'1`K!PO?SWY.T`
MORWI\$]+\C`5"WC`\@(%#$:%L#TK*F@(OP$T!D8@1@.2_/=*[@*I!T8P1O_W
M>?^`1@`H5-#\]T#NAT)'V0*;2_(H&<#R`@E/ZH,(,'@`*!B_/2@4OP$@`"`'
MT#!&$/@!/P`K&+\]*_G1@!L"-]GX`*`X1/SW_NU*^`@``"ANT-GX`"!Q'`*8
M,WA2^"``/2L8OP`K`W`)T$(<$?@!.Q!&`"L8OSTK`O@!._;1`D8](P-P%/@!
M.P+X`3\`*_G1`"`#FBMHFD)-T06PO>CPCPCQ_S`4^`$[`/@!/P`K^='NYTOR
M*!G`\@()V?@`L-OX`#"3LUM&`.!01E/X!"\`\0$*`"KXT0,P@`!+\E@2P/("
M`A-H@[$!1EA&_/=J[<GX``#HL4_JB@@*\0$#`")`^",@S?@(H(KG`2,38/SW
MFNT!D&BQ3^J*"%E&0D;\]P#M`9L81LGX`##FYYI&""#4YT_P_S"MY_SW,.T`
MORWI\$-+\C`5P/("!9^P*V@=DQ"Q`W@'1C.Y'9HK:)I"4]$?L+WH\(/\]V+M
M!D8`*//01?;,6,#R`0@P1OSW"NZ`L\-\+BLTT`#Q$P0X1OSW@.V!1B!&_/=\
M[4A$`C#\]U3M0T9/\/\R`2$!E`"7@4;\]X;M248"J@,@_/?^[0$P2$8%T`:;
M`_1P0[/U@$\9T/SW\NQ(1OSWK.PP1OSWVNT`*,[1,$;\]P;N.$;\][[LL^<#
M?0`KP-`N*\710WT`*[O0P>?_]YS_Y.?\]\CL`+\XM4OR.!3`\@($!48@:/SW
M\.TI1@#UI'(#(/SWWNT(L0`@.+T@:/SWY.W0^%@Q`_1P0[/U@$\)T"!H_/?:
M[=#X6#$#]'!#L_4@3^G1*$8"(?SW@.VP^H#P0`DXO?"U2_(P%*WU@%W`\@($
M@[`&1B-H#?6`500U#T9%]M10`:G`\@$`0/;_<BM@_/>F[``H(]U%'@&K6UWK
ML05&*D8O(0&H_/=2[<"Q2_(X$\#R`@,8:/SWGNTK1@&J,4;\]VKM#?6`4P0S
M&F@C:)I"$=$-]8!=`[#PO0`MX-%+\C@3P/("`QAH_/>&[3I&,4;\]W#LYN?\
M]TSL2_(X$\#R`@,0M1AH_/=V[47V4%-!\C!21?;D4<#R`0/`\@$"P/(!`;WH
M$$#\]]J\$+5+\C@4P/("!(*P(&C\]U[M__?=_R!H_/=8[0`A1O+<`P&1P/(!
M`T7V"2(`D\#R`0)%]@!AP/(!`?SW[NP"L!"]`+]PM4OR,!2M]0!=P/("!(:P
M(V@-]0!2%#(38/SW<NQ%]B1B1?888\#R`0+`\@$#`9(!(4'R`0(`D`.H_/>&
M[``H(ML-]8!1`ZA/](!2$#'\]Q#L!1X8VV@<_/<Z[`9&J+$-]8!1*D80,?SW
MLNLP1@`C<U4-]0!3%#,::"-HFD(&T0WU`%T&L'"]`"#RY_'G_/?*ZP"___>T
MORWI\$]+\C`6K?6!7<#R`@:!L`1&,V@-]8!2'#(/1D7V+&`&J<#R`0`38/_W
M7?TO(05&($;\]S#LH+%%]CA@(4;`\@$`__?`_2!&#?6`4QPS&F@S:)I"0/"3
M@`WU@5T!L+WH\(\@1OSW#.Q%]DAAP/(!`8)&.$;\]W3L@48`*-S01?8H9T7V
M3&C`\@$'P/(!"$7V5&/`\@$#!9.9^``P`"L(O[E&+;%)1BA&_/<<ZP`H2M!(
M1OSWY.M!'@GK`0,9^`$0+RD(T4_P``Z#^`#@`3@3^`$=+RGXT`KQ`0,81+#U
M@%^JV@6;2_(X&\#R`@M/](!2`2$"E`&3!ZA#1LWX`)#\]];KV_@``/SW<NP'
MJ0#UI'(#(/SW2.Q0N=OX``#\]VCLT/A8,0/T<$.S]0!/%M!%]DAA`"#`\@$!
M_/<2[(%&N?$`#ZG1>.=%]DAAP/(!`?SW!NR!1KGQ``^>T6WG`2$'J/SW^.L`
M*.+1!ZE%]CA@P/(!`/_W*/T'J/SWJ.MDY_SW!.L#>#NQ0APO*PB_$$82^`$[
M`"OXT7!'`+\XM7BS!7@$1F6S_/=LZP$X(AB40@S2(UPO*RS14QX"X!%X+RDG
MT:-"&D8#\?\S]]&40BS0`3H#X!%X+RD$T1I&E$("\?\S]],2&Y,<L_6`7P_8
M`3(A1D_T@%,22/SWPNH02#B]`B#\]QKK$+$N(@*`.+T`(#B]4QX"X!%X+RG9
MT)Q"&D8#\?\S]].40M+1+RWHT$7V5&#`\@$`O>@X0/SW1;L`OURQ`@#PM8VP
M7TT"K$OR,!;`\@(&#\TW:`_$#\T+ERUH#\1%]EA@P/(!`"6`__=\_$7V9&#`
M\@$`__=V_$7V;&#`\@$`__=P_$7V>&#`\@$`__=J_$7V@&#`\@$`__=D_$7V
MD&#`\@$`__=>_$7V+&#`\@$`__=8_$7VG&#`\@$`__=2_$7VJ&#`\@$`__=,
M_$7VM&#`\@$`__=&_$7V.&#`\@$`__=`_$7VP&#`\@$`__<Z_$7VS&#`\@$`
M__<T_$7VV&`!J<#R`0#_]^W[,+$!1D7VJ&#`\@$`__=5_$7V[&`!J<#R`0#_
M]][[,+$!1D7V`'#`\@$`__=&_$7V#'`!J<#R`0#_]\_[L+$!1D7V+&#`\@$`
M__<W_$7V/'%%]H!@P/(!`<#R`0#_]RW\"YHS:)I")=$-L/"]1?8<<`&IP/(!
M`/_WL/LXL0%&1?:<8,#R`0#_]QC\W^=%]C!Q"B+`\@$!#?$9`/SW!.L`*-31
M1?:<8`WQ(P'`\@$`__<$_,OG_/?DZ0"_7%T!`#"U2_(P%,#R`@1+\B`5P/("
M!8.P(V@H:`&30QP%T`&:(VB:0A+1`[`PO47VG&!I1L#R`0#_]W+[,+$`>#`H
M&+\`*!2_`2``("A@Z.?\][CI"+7\]W3I_/=FZ0"Q`&@(O2WI\$\'1BQ,C[`&
MK4OR,!C`\@((#\S8^`!@#\64Z`<`!IP-EH7H!P`,LT7V2&I%]DQIP/(!"L#R
M`0D&K0;@.4;\]S3IV+%5^`1/A+$%J2!&__<T^P9&$+$#>``K[]$@1CE&__>;
M^U7X!$\`+.[1#9K8^``PFD(=T0^PO>CPCSA&_/?HZ8-&,$;\]^3I6$0",/SW
MO.D"EDM&S?@$H$_P_S(`EP$A@T;\]^[I648@1O_W=?O(Y_SW5.F`70$`+>GP
M3P=&A4RM]0%-D;!+\C`3!/$,#A*NE.@'`,#R`@,(DQBM)#0-\50(AN@'`+[H
M#P`/Q9[H`P`(FX7H`P"4Z`<`#?4!1!MH/#2(Z`<`1?8L8!&IP/(!`"-@__?1
M^B"Q`W@$1@`K0/"*@?_W8_\%1@`H4=`H1OSWD.E```$P_/=HZ2MX1?9(><#R
M`0F`1@1&8[$`DR!&2T9/\/\R`2$"-/SWDND5^`$_`"ORT1B8&*P8N13@5/@$
M#XBQ$:G_]Z#Z!48`*/;0`W@`*_/0__<D_``H[]`H1OSWANF!1F"[$IQ$LR-X
M`24SN23@5O@E0`RS(W@!-?.Q($;_]P[\`"CTT"!&_/=PZ0`H[]"!1A3@_/=J
MZ0`H0/`Q@5CX!`L`*`#P-($1J?_W;/H`*/70`W@`*_+0[.=/\``)2$9%]E1K
M_/<LZ<#R`0L$1D!&_/<FZ2!$`/($1"!&_/?\Z`$AS?@,@$7V7'+-^`"0P/(!
M`LWX!+!%]E!S`I+`\@$#3_#_,H)&_/<BZ5!&3_3@<?SW.ND!,"S02_(X%<#R
M`@4H:/SWM.E11@#UI'(#(/SWHND`*#?02_)`$<#R`@$[:$7VY'((:,#R`0+-
M^`"@`2'\]S[I`"`-]0%#/#,::`B;&VB:0D#PF((-]0%-$;"]Z/"/_/?FZ`%H
M$2G-T$OR0!#`\@(`.VA%]F1R`&C`\@$"`9$!(<WX`*#\]QKI`"#:YP"_G%T!
M`"AH_/=RZ=#X6#$#]'!#L_6`3[W1*&C\]VCIT/A@8?OW\.^&0K31*&C\]U[I
MT/A8,</S"`.S]>!_JM$@1OSW>.@1J01&1O(P$,#R`0#_]\CY`"@`\)"`/6C\
M][3H`48H1O_W2OP%1@`H`/"%@"A&_/>$Z`,H!D81W00X1?:@<2A$P/(!`?OW
MJN]`N00N`/#4@2Y$%O@%/"\K`/#.@?_W$OXPN0%&*$;\]S[H"9``*&311?8\
M<47VG&#`\@$!P/(!`/_W_OE&\MP'_/=*Z,#R`0?-^`2P1?;`<P.7P/(!`\WX
M`*!/\/\R`2%%]M!XN4;`\@$(`"971@*0($;\]U;H%.#\]TSH`V@1*Q?1_/<J
MZ`$VS?@0D"I&`Y9#1LWX!+`!(0"7`I`@1OSW0.A/].!Q($;\]U;H0QP%1N+0
MND901OOW;.\A1D7V+&#`\@$`__>X^2!&__?G_2!&*N<%1GKF__?A_2!&_/<N
MZ"+G1?9`=0T@P/(!!7/F/6AXYT_P_S-O\!$"`B4`E?OWO.]/J08B"9C[]S#O
MG?@\,2.YG?@],4,K`/!O@0`E`"(`(P"5"9C[]ZCOT:'1Z0`!T:/3Z0`C/)7-
MZ2`!+*D*D<^AT>D``<WI(B//H]/I`"/-Z20!SJ'1Z0`!S>DF(P`B`",+E,WI
M*"/-Z2HCS>D>`<WX,*#-^#2P3_0`0D^I"9C[]_3N!!YVW=WI*`%/ZL0*`"<B
M1AKK``:/0@B_AD)/ZN1S8=/=Z2J)50\&E0:9/)U!ZL,!6P\&D0>3W>D&`<WI
M*&<0ZP@`0>L)`<WI*@$`+4C0Q?%`!PJ;IT)/J0/K!0"HOR=&.D;[]^#N/)L[
M1#R30"O!T4^K'JCD&Q]$_/>`^3\L)]U`/`?Q0`Q/ZI09"?$""`?KB!BL\4`%
M#?&P#BAH$#55^`P<=D95^`@L#O$0#E7X!#QE10_&\=$>J/SW8/D%\4`,Q$7F
MT0GQ`0.DZXD4!^N#%SE&2",B1@J8^_?Z[CR4B>=/K\OGW>DJ`1#Q`0A!\0`)
MF.<+K`F8+*^4Z!`,^_?<[X`A*)TJGL7SQ0)3'#@KN50`\Z*`^!C#\3@"`"'[
M]V#O'J@J#C,.C?CK8(WX[U`-]8AYC?CH,#,,C?CL(#8*C?CI,"L,C?CJ8"T*
MC?CM,$7V2'B-^.Y0_/<1^2*:#?(/%1Z8P/(!"""9/Z^-^`<A!@P##HWX_P``
M"HWX`Q&-^/X`"`Z-^``!"`P)"HWX`0&-^`(1$`H1#HWX!!$1#"::C?@%$229
MC?C]8$Y&C?@&`8WX"Q$(#HWX#R&-^`@!"`R-^/PP"0J-^`D!C?@*$1$.C?@,
M$1$,$@J-^`T1C?@.(0'@%_@!/P"3,$9#1D_P_S(!(0(V^_?4[KU"\M'-^`B0
M`"#-^`2P1O+<`LWX`*#`\@$"1?:P<P.2P/(!`XGX*`!/\/\R`2$@1OOWNNZ!
MYGYH`"X_]"ZN,$;[]YKN`RA_]BBN!#A%]JAQ,$3`\@$!^_?`[0`H"+\U1AOF
MP_%``O@8`"'[][[N'JC\]XGX.$8X(@`A^_>V[E3GG?@^,4$K?_2,KIWX/S%#
M*W_TAZZ=^$`Q2"M_](*NG?A!,44K?_1]K@"53_#_,PF=;_`Y`BA&^_<B[D^I
M*$8I(OOWF.U/J\WX!+!&\MP"`I/`\@$"S?@`H$7VL',#DL#R`0-/\/\R`2$@
M1OOW7.XDYOOWR.T`OXFKS>\`````_MRZF`````!V5#(0`````/#ATL,`````
M`2-%9P`````MZ?!/2_(P$X6PP/("`TOR.!?`\@('`9,;:#AH`Y/[]]3N`2,"
MJ8#X93!%]H!@P/(!`/[W1?\8L0-X,2L`\,&`__?L^CAH3/)0)OOWONY&\C@!
M"R/`\@$!`2+`\@(&^_?D[0`H/M!6^/0\`FD!*]+X&)`WW4_T@&H`)<#R(`H!
M)"#@`6A6^/`,BVA0^"2`"NH#`[/U@&\(OPEI"=`X:/OWE.[;^``0`B,`(OOW
MCNT!1D!&^_<$[5;X]#R`N0$T`36C0@S=.&C[]X#N`",J1DE&^_<X[H-&`"C3
MT5;X]#Q:'JI"7]`X:/OW<.Y&\D`!`R/`\@$!`2+[]YCM!$:`L3AH^_=B[B-I
M1O)$`L#R`0(9:/OW2.TC:1MHFVA;`@#QI(`X:/OW4NY&\DP!`R/`\@$!`2+[
M]WKM!$:0L47V.&`"J<#R`0#^][S^!48X:``M`/"!@/OW.NXC:2I&&6C[]R+M
M.&C[]S+N`","J8#X93!%]BQ@P/(!`/[WH_X%1D;X[`P@LT_TX''[]YSM0QP1
M*!B_`2MYV`&;`YH;:)I"<M$%L+WH\(\!*YW=`20X:`$T^_<,[DE&^_>F[%;X
M]#RC0O3<D.=#>``K/_0]KSGG5OCP#/_W=OM&^.P,`"A-T"-I3_2`8L#R(`(9
M:(MH$T"S]8!O"+\(:0C0.&C[]^;M(6DJ1@(C"6C[]^#L5OCP7"E&^_>&["-I
M3_2`8L#R(`(M:!EHBV@30+/U@&\(OPII!D8)T#AH^_?*[2%I`"("(PEH^_?$
M[`)&1O)T`#-&*4;`\@$`^_<@[?OWN.U6^/`L(VD1:!AH_O?G_WOG.&C[]Z[M
M(VD9:/OW/NU3YT;R4`#`\@$`^_<([?OW;NQ6^/`<`T8J1D;RG`#`\@$`"6C[
M]_SL`+\XM05&__=F^0-X!$8[L4(<+RL(OQ1&$O@!.P`K^-'_]W'Z`"T8OP`H
M"M`K>$.Q1?9<<2!&P/(!`?OWZNN$0@#0.+TH1KWH.$#^]PZ_`DM[1`.Q&VC[
M]SR\(E0!`"WI^$,'1@M.B$8+39%&?D3[]\#K?41V&[80"=``)`$T5?@$.TI&
M048X1IA'M$+VT;WH^(/B40$`V%$!`'!'`+\(0"WI"("]Z`$``@!P97)L>'-I
M+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````080$`
M(&$!`"AA`0`P80$`.&$!`$QA`0``````"&$!`"A>`0```````%\!``1?`0#\
M8`$`,%X!``1A`0``````Z&`!`/!@`0``````)7,O)7,````O<')O8R]S96QF
M+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ
M4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````
M4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!0
M15),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10``
M`%!!4E]!4D=#`````%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````
M4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````4UE35$5-
M```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S
M````)7,E<W1E;7`M)74M)74E<P`````E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*``!!4D=6`````!@```!P97)L`````#````!5;F%B
M;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N
M(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``
M+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`
M````1%E,1%],24)205)97U!!5$@```!32$Q)0E]0051(``!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D
M14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'
M5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[
M4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T
M92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP
M*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@
M;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW
M:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE
M.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D
M(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D
M8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M
M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD
M97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@
M)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F
M9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M
M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U
M9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H
M56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F
M:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2![
M"F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*
M8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN
M86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M
M921E>'0B.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D
M;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D[
M"G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C
M86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE
M(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D
M:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E
M='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[
M8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM
M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M
M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U
M="`D9FEL96YA;64M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H
M+"`G/"<L("1N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD
M("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D[
M"F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G
M)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E
M;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN
M;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S
M<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@
M*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D
M96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]
M?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A
M;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N
M("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@
M>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I
M;F,@/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@
M>PHA+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE
M<SL*+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@
M:V5Y<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E
M;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F
M:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0[
M"GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@
M9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C
M;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N
M86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A
M;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!
M,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D
M9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@
M86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE
M(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4[
M"F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005([
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I
M;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S
M86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@
M6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY
M("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B
M87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P
M87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R![
M"G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT
M96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I
M<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^
M(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D
M<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I
M9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@
M(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT
M:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL
M92!["FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I
M.PHD9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M
M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@
M*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@
M)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F
M:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G
M;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF
M:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*
M?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE4
M24%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$
M14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``A'K_?P$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$T:`0`U&@$```````$````!`````0```-,!```!````
M(@(```$```!U`P``#````)@4`0`-````1%T!`!D```#TK@(`&P````0````:
M````^*X"`!P````$````]?[_;[0!`0`%````)`P!``8```!D!0$`"@```/$$
M```+````$````!4``````````P````"P`@`"````$`(``!0````1````%P``
M`(@2`0`1````4!(!`!(````X````$P````@```#^__]O\!$!`/___V\#````
M\/__;Q81`0``````````````````````````````````````````````````
M````````````````KP(```````````"D%`$`I!0!`*04`0"D%`$`I!0!`*04
M`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!
M`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`
MI!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D
M%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04
M`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!`*04`0"D%`$`I!0!
M`*04`0"D%`$`I!0!`*04`0````````````````#_____6&$!`$=#0SH@*%5B
M=6YT=2],:6YA<F\@-2XS+C$M-G5B=6YT=3$I(#4N,RXQ(#(P,38P,3$T`$=#
M0SH@*%5B=6YT=2],:6YA<F\@-"XY+C,M.'5B=6YT=3(I(#0N.2XS`$$R````
M865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B
M`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB
M=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO
M;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X
M=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R
M<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````
M```````````````````````````````+`````0````(```!4`0$`5`$``!D`
M``````````````$`````````$P````<````"````<`$!`'`!```@````````
M```````$`````````"$````'`````@```)`!`0"0`0``)```````````````
M!``````````T````]O__;P(```"T`0$`M`$``+`#```%``````````0````$
M````/@````L````"````9`4!`&0%``#`!@``!@````$````$````$````$8`
M```#`````@```"0,`0`D#```\00``````````````0````````!.````____
M;P(````6$0$`%A$``-@````%``````````(````"````6P```/[__V\"````
M\!$!`/`1``!@````!@````,````$`````````&H````)`````@```%`2`0!0
M$@``.`````4`````````!`````@```!S````"0```$(```"($@$`B!(``!`"
M```%````%@````0````(````?`````$````&````F!0!`)@4```,````````
M```````$`````````'<````!````!@```*04`0"D%```.`,`````````````
M!`````0```""`````0````8```#@%P$`X!<``&1%``````````````@`````
M````B`````$````&````1%T!`$1=```(```````````````$`````````(X`
M```!`````@```$Q=`0!,70``P$$`````````````!`````````"6`````0``
M<((````,GP$`#)\```@````-``````````0`````````H0````$````"````
M%)\!`!2?```$```````````````$`````````*L````.`````P```/2N`@#T
MK@``!```````````````!`````````"W````#P````,```#XK@(`^*X```0`
M``````````````0`````````PP````$````#````_*X"`/RN```$````````
M```````$`````````,@````&`````P````"O`@``KP````$```8`````````
M!`````@```#1`````0````,`````L`(``+```!@!``````````````0````$
M````U@````$````#````&+$"`!BQ```0```````````````$`````````-P`
M```(`````P```"BQ`@`HL0``1!``````````````"`````````#A`````0``
M`#``````````*+$``%T```````````````$````!````Z@````,``'``````
M`````(6Q```S```````````````!``````````$````#``````````````"X
7L0``^@```````````````0``````````
